==> monodevelop_5.5.0.227.orig.tar.bz2: monodevelop-5.5/src/addins/MonoDevelop.PackageManagement/MonoDevelop.PackageManagement/SelectProjectsService.cs <==
﻿// 
// SelectProjectsService.cs
// 
// Author:
//   Matt Ward <ward.matt@gmail.com>
// 
// Copyright (C) 2013 Matthew Ward
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;
using MonoDevelop.Ide;
using MonoDevelop.PackageManagement;

namespace ICSharpCode.PackageManagement
{
	public class SelectProjectsService : ISelectProjectsService
	{
		public bool SelectProjects(IEnumerable<IPackageManagementSelectedProject> projects)
		{
			SelectProjectsDialog dialog = CreateSelectProjectsDialog(projects);
			int result = MessageService.ShowCustomDialog(dialog);
			return result == (int)Gtk.ResponseType.Ok;
		}
		
		SelectProjectsDialog CreateSelectProjectsDialog(IEnumerable<IPackageManagementSelectedProject> projects)
		{
			var viewModel = new SelectProjectsViewModel(projects);
			return new SelectProjectsDialog(viewModel);
		}
	}
}

==> monodevelop_5.10.0.871.orig.tar.bz2: monodevelop-5.10/src/addins/MonoDevelop.PackageManagement/MonoDevelop.PackageManagement/SelectProjectsService.cs <==
﻿// 
// SelectProjectsService.cs
// 
// Author:
//   Matt Ward <ward.matt@gmail.com>
// 
// Copyright (C) 2013 Matthew Ward
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;
using MonoDevelop.Ide;
using MonoDevelop.PackageManagement;

namespace ICSharpCode.PackageManagement
{
	public class SelectProjectsService : ISelectProjectsService
	{
		public bool SelectProjects(IEnumerable<IPackageManagementSelectedProject> projects)
		{
			using (SelectProjectsDialog dialog = CreateSelectProjectsDialog (projects)) {
				int result = MessageService.ShowCustomDialog (dialog);
				return result == (int)Gtk.ResponseType.Ok;
			}
		}
		
		SelectProjectsDialog CreateSelectProjectsDialog(IEnumerable<IPackageManagementSelectedProject> projects)
		{
			var viewModel = new SelectProjectsViewModel(projects);
			return new SelectProjectsDialog(viewModel);
		}
	}
}
